@@ -26,6 +26,17 @@ def workspace_path(context):
         click.echo(str(anyrepo.path))
 
 
+@info.command()
+@pass_context
+def main_path(context):
+    """
+    Print Path to Main Git Clone.
+    """
+    with exceptionhandling(context):
+        anyrepo = AnyRepo.from_path()
+        click.echo(str(anyrepo.workspace.main_path))
+
+
 @info.command()
 @groups_option()
 @pass_context
@@ -35,6 +46,6 @@ def project_paths(context, groups):
     """
     with exceptionhandling(context):
         anyrepo = AnyRepo.from_path()
-        for project in anyrepo.iter_projects(filter_=anyrepo.create_groups_filter(groups)):
+        for project in anyrepo.projects(filter_=anyrepo.create_groups_filter(groups)):
             project_path = anyrepo.workspace.get_project_path(project)
             click.echo(project_path)
